import "classes/*.pp"
import "common/*.pp"
import "/etc/puppet/modules/module-svn/manifests/*.pp"

import "node-prod-estaciones.pp"
import "node-prod-servidores.pp"

# Create "/tmp/testfile" if it doesn't exist.
class test_class {
    file { "/tmp/testfile":
       ensure => present,
       mode   => 644,
       owner  => root,
       group  => root
    }
}

# tell puppet on which client to run the class
node peon {
    include test_class
    include estacion-de-trabajo
}

node ardizzone {
    include test_class
    include audiostreamer

    debproxy::activateclient { dist:
       debproxyhost => "debproxy",
    }

}

node walsh {
    include test_class

    include ubuntu::optimizacion

    include utile-cli

    debproxy::activateclient { dist:
       debproxyhost => "debproxy-ubuntu",
    }

    cronapt::mailon-mailto { dist:
       mailon => "upgrade",
       mailto => "seguridad@localhost"
    }

    include estacion-de-trabajo

    ubuntufirefox::startuppage { dist:
       startuppage => "http://www.sedenacional.cta.org.ar",
    }

    ltsp::buildclient { dist:
        mirror => "http://debproxy-ubuntu:3142/ar.archive.ubuntu.com/ubuntu",
        securitymirror => "http://debproxy-ubuntu:3142/security.ubuntu.com"
    }

    include ltsp::tftpdhpa::activate

    include matrix::ldapauthclient

    # mount samba shared
    package {
         [ "smbfs" ]: ensure => installed;
     }

    file { ["/home"]:
      ensure => directory,
      owner => "root", group => "root", mode => "755"
    }
    file { ["/home/sedenacional-prensa"]:
      ensure => directory,
      owner => "root", group => "sedenacional-prensa", mode => "770"
    }

    file { ["/home/sedenacional-internacional"]:
      ensure => directory,
      owner => "root", group => "sedenacional-internacional", mode => "770"
    }

    file { ["/home/sedenacional-observatorio"]:
      ensure => directory,
      owner => "root", group => "sedenacional-observatorio", mode => "770"
    }

    file { ["/home/sedenacional-genero"]:
      ensure => directory,
      owner => "root", group => "sedenacional-genero", mode => "770"
    }

     mount { "/home/sedenacional-prensa":
         atboot   => true,
         device   => "//tupac/prensa",
         ensure   => mounted,
         fstype   => "smbfs",
	 remounts => false,
	 options  => "credentials=/root/smb-prensa,dir_mode=0770,gid=10048,iocharset=utf8",
         require  => package["smbfs"],
     }

     mount { "/home/sedenacional-internacional":
         atboot   => true,
         device   => "//tupac/internacional",
         ensure   => mounted,
         fstype   => "smbfs",
         remounts => false,
         options  => "credentials=/root/smb-internacional,dir_mode=0770,gid=10049,iocharset=utf8",
         require  => package["smbfs"],
     }

     mount { "/home/sedenacional-observatorio":
         atboot   => true,
         device   => "//tupac/observatorio",
         ensure   => mounted,
         fstype   => "smbfs",
         remounts => false,
         options  => "credentials=/root/smb-observatorio,dir_mode=0770,gid=10050,iocharset=utf8",
         require  => package["smbfs"],
     }

     mount { "/home/sedenacional-genero":
         atboot   => true,
         device   => "//tupac/genero",
         ensure   => mounted,
         fstype   => "smbfs",
         remounts => false,
         options  => "credentials=/root/smb-genero,dir_mode=0770,gid=10051,iocharset=utf8",
         require  => package["smbfs"],
     }


}

node zara  {
    include test_class
}
